<?php 

/*
Plugin Name: Event-O-Matic
Plugin URI: http://garvinmedia.com
Description: The Event Management Plugin for Wordpress
Version: 6.0.1
Author: Matthew Garvin
Author URI: http://garvinmedia.com
Text Domain: eom
*/


/**
 * loads custom post type into system
 *
 * @since 5.0
 */
add_action( 'init', 'eom_init', 0 );
function eom_init() {
	
	//get eom_event_slug option, or default
	$event_slug = get_option( 'eom_event_slug', 'events' );
	$event_rewrite = array(
		'slug'                	=> _x( $event_slug, 'URL slug', 'eom' ),
		'with_front'          	=> true,
		'pages'               	=> true,
		'feeds'               	=> true,
	);
	$event_args = array(
		'label'               	=> __( 'Events', 'eom' ),
		'labels'              	=> array(
			'name_admin_bar'  	=> __( 'Events', 'eom' ),
			'new_item'        	=> __( 'New Event', 'eom' ),
			'name'            	=> _x( 'Events', 'Post Type General Name', 'eom' ),
			'singular_name'   	=> _x( 'Event', 'Post Type Singular Name', 'eom' ),
			'menu_name'       	=> __( 'Events', 'eom' ),
			'parent_item_colon'	=> __( 'Parent Event:', 'eom' ),
			'all_items'       	=> __( 'All Events', 'eom' ),
			'view_item'       	=> __( 'View Event', 'eom' ),
			'add_new_item'    	=> __( 'Add New Event', 'eom' ),
			'add_new'         	=> __( 'Add New Event', 'eom' ),
			'edit_item'       	=> __( 'Edit Event', 'eom' ),
			'update_item'     	=> __( 'Update Event', 'eom' ),
			'search_items'     	=> __( 'Search Events', 'eom' ),
			'not_found'         => __( 'Not found', 'eom' ),
			'not_found_in_trash'=> __( 'Not found in Trash', 'eom' ),
		),
		'description'         	=> __( 'Events & Happenings', 'eom' ),
		'public'              	=> true,
		'exclude_from_search' 	=> false,
		'publicly_queryable'  	=> true,
		'show_ui'             	=> true,
		'show_in_nav_menus'   	=> false,
		'show_in_menu'        	=> true,
		'show_in_admin_bar'   	=> true,
		'menu_position'       	=> 10,
		'menu_icon'           	=> 'dashicons-calendar',
		'capability_type' 		=> 'post',
		'hierarchical'        	=> false,
		'supports'          	=> array( 'title', 'editor', 'thumbnail', 'comments', 'author' ),
		'register_meta_box_cb'	=> 'eom_meta_box_add',
		'taxonomies'         	=> array( 'eom-event-cats' ),
		'has_archive'         	=> true,
		'rewrite'             	=> $event_rewrite,
		'query_var' 			=> true,
		'can_export'          	=> true,
	);
	register_post_type('eom-event', $event_args); // register post type
	
	$place_rewrite = array(
		'slug'                	=> _x( 'places', 'URL slug', 'eom' ),
		'with_front'          	=> true,
		'pages'               	=> true,
		'feeds'               	=> false,
	);
	$place_args = array(
		'label'               	=> __( 'Places', 'eom' ),
		'labels' 				=> array(
			'name_admin_bar'  	=> __( 'Places', 'eom' ),
			'new_item'        	=> __( 'New Place', 'eom' ),
			'name'            	=> _x( 'Places', 'Post Type General Name', 'eom' ),
			'singular_name'   	=> _x( 'Place', 'Post Type Singular Name', 'eom' ),
			'menu_name'       	=> __( 'Places', 'eom' ),
			'parent_item_colon'	=> __( 'Parent Place:', 'eom' ),
			'all_items'       	=> __( 'All Places', 'eom' ),
			'view_item'       	=> __( 'View Place', 'eom' ),
			'add_new_item'    	=> __( 'Add New Place', 'eom' ),
			'add_new'         	=> __( 'Add New Place', 'eom' ),
			'edit_item'       	=> __( 'Edit Place', 'eom' ),
			'update_item'     	=> __( 'Update Place', 'eom' ),
			'search_items'     	=> __( 'Search Places', 'eom' ),
			'not_found'         => __( 'Not found', 'eom' ),
			'not_found_in_trash'=> __( 'Not found in Trash', 'eom' ),
		),
		'description'         	=> __( 'Locations to see.', 'eom' ),
    	'public' 				=> true,
		'exclude_from_search'	=> false,
		'publicly_queryable' 	=> true,
    	'show_ui' 				=> true, 
    	'show_in_nav_menus'   	=> false,
		'show_in_menu' 			=> true,
		'show_in_admin_bar'   	=> false,
		'menu_position'       	=> 10,
		'menu_icon'           	=> 'dashicons-location-alt',
		'capability_type' 		=> 'post',
		'hierarchical'        	=> false,
		'supports' 				=> array( 'title', 'editor', 'thumbnail'),
		'register_meta_box_cb'	=> 'eom_meta_box_add',
		'has_archive' 			=> true,
		'rewrite' 				=> $place_rewrite,
		'query_var' 			=> true,
		'can_export'			=> true,
 	); 
	register_post_type('eom-place', $place_args);
	
	register_taxonomy(
		'eom-event-cats',
		array('eom-event'),
		array(
			'hierarchical' => true,
			'labels' => array(
				'name' => _x( 'Event Categories', 'taxonomy general name', 'eom'  ),
				'singular_name' => _x( 'Event Category', 'taxonomy singular name', 'eom' ),
				'search_items' =>  __( 'Search Event Categories', 'eom' ),
				'all_items' => __( 'All Event Categories', 'eom' ),
				'parent_item' => __( 'Parent Category', 'eom' ),
				'parent_item_colon' => __( 'Parent Category:', 'eom' ),
				'edit_item' => __( 'Edit Category', 'eom' ), 
				'update_item' => __( 'Update Category', 'eom' ),
				'add_new_item' => __( 'Add New Category', 'eom' ),
				'new_item_name' => __( 'New Category Name', 'eom' ),
				'menu_name' => __( 'Categories', 'eom' ),
			),
    		'show_ui' => true,
			'show_admin_column' => true,
    		'query_var' => true,
    		'rewrite' => array( 'slug' => 'event_category' ),
 		)
	);
	
}



/**
 * rewrites flush to correct any permalink issues
 *
 * @since 5.0
 */
function eom_rewrite_flush() {
	eom_init(); //run the cpt loader
	flush_rewrite_rules(); //flush the rules
}
register_activation_hook( __FILE__, 'eom_rewrite_flush' );



/**
 * loads translation
 *
 * @since 5.0
 */
function eom_load_translation() {
	load_plugin_textdomain( 'eom', false, basename(dirname(__FILE__)).'/langs/' );
}
add_action('plugins_loaded', 'eom_load_translation');



/**
 * hooks meta boxes
 *
 * @since 1.0
 */
function eom_meta_box_add(){  
   	add_meta_box( 'eom-place', __('Address','eom'), 'eom_place_meta', 'eom-place', 'side', 'high' );
	add_meta_box( 'eom-event', __('Date & Location','eom'), 'eom_event_meta', 'eom-event', 'side');
	add_meta_box('eom-events-at-place', __('Events','eom'), 'eom_events_at_place_meta', 'eom-place' );
}



/**
 * creates date & location meta box for eom-event
 *
 * @since 5.0
 */
function eom_event_meta( $post ){
	$values = get_post_meta( $post->ID);
	
	$start = isset( $values['eom-date-start'][0] ) ? esc_attr( $values['eom-date-start'][0] ) : time(); 
	$end = '1'; 
	if(isset( $values['eom-date-end'][0] )){
		$end = ($values['eom-date-end'][0] - $values['eom-date-start'][0]) / 3600;
	}
	
	$place = isset( $values['eom-place'] ) ? esc_attr( $values['eom-place'][0] ) : ''; 
	//format dates from timestamp
	$date_start = date( eom_format_date('phpforjs'), $start );
	
	wp_nonce_field( 'eom-event','eom_nonce' ); ?>
	
	<p><?php eom_date_field('eom-date-start', $date_start); eom_time_select('eom-time-start', $start); ?><br />
	and continues for <input type="text" name="hours_end" size="2" value="<?php echo $end; ?>" /> hours</p>
	<?php printf(__('<p>Choose a place below or <a href="%s">create a new one</a>:</p>','eom'),
	esc_url('post-new.php?post_type=eom-place'));
	echo eom_select_post_type('eom-place','eom-place', $place);
	
	//eom_select_post_type($name, $post_type, $selected='', $status='publish')
}



/**
 * creates address meta box for eom-place
 * 
 * @since 5.0
 */
function eom_place_meta($post){
	$address = get_post_meta( $post->ID, 'eom-address', true );
	wp_nonce_field( 'eom-place','eom_nonce' ); 
	if($address): //build map ?>
		<img src ="//maps.googleapis.com/maps/api/staticmap?size=250x250&maptype=roadmap
&markers=color:blue%7C<?php echo urlencode($address);?>&sensor=false" />
	<?php endif; ?>
	<label for="address"><?php _e('Address:','eom');?></label><br /> 
	<textarea rows="3" name="eom-address"><?php esc_attr_e($address); ?></textarea>
	<?php
}



/**
 * creates meta box for eom-place showing events at that place
 * 
 * @since 5.0
 */
function eom_events_at_place_meta($post){
	$args = array('posts_per_page' => -1, 
		'meta_key' => 'eom-date-start',
		'orderby' => 'meta_value_num',	
		'post_type' => 'eom-event', 
		'post_status' => 'all', 
		'meta_query'=> array(//'relation' => 'AND',
			array( 'key' => 'eom-place', 'value' => $post->ID ),
			//array( 'key' => 'eom-date-start', 'value' => time(), 'compare' => '>')			
		));
	$events = get_posts( $args );
	if($events){?>
		<table class="wp-list-table widefat"><thead><tr>
			<th><?php _e('Name', 'eom'); ?></th>
			<th><?php _e('Date', 'eom'); ?></th>
			<th><?php _e('Status', 'eom'); ?></th>
		</tr></thead><tbody>	
		<?php foreach($events as $event){
			$start = get_post_meta($event->ID, 'eom-date-start', true);
			$start = date(eom_format_date('php'), $start);
			echo '<tr><td><a href="post.php?post='.$event->ID.'&action=edit">'.esc_html( $event->post_title ).'</a></td><td>'.$start.'</td><td>'.$event->post_status.'</td></tr>';
		}
		echo '</tbody></table>';
	}
}



/**
 * Saves meta information
 *
 * @since 5.0
 */
add_action( 'save_post', 'eom_meta_save' );
function eom_meta_save( $post_id ){
	if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return; // doing an auto save, bail 
	if( !current_user_can( 'edit_posts' ) ) return; // if current user can't edit post, bail
	if( !is_admin() ) return; // only for admin backend
	
	if( isset($_POST['eom-place'])){ // place selection on eom-event
		if(check_admin_referer( 'eom-event', 'eom_nonce' )){
			update_post_meta( $post_id, 'eom-place', esc_attr($_POST['eom-place'])); //update place
		}
	}
	if( isset($_POST['eom-date-start'] )){ // date selection on eom-event
		if(check_admin_referer( 'eom-event', 'eom_nonce' )){
			$event_start = strtotime($_POST['eom-date-start'].' '.$_POST['eom-time-start']);
			$event_end = $_POST['hours_end']*3600+$event_start;
			update_post_meta( $post_id, 'eom-date-start', $event_start );
			update_post_meta( $post_id, 'eom-date-end', $event_end );
		}
	}
	if( isset( $_POST['eom-address'] ) ){ // address selection on eom-place
		if(check_admin_referer( 'eom-place', 'eom_nonce' )){ 
			try{
				$results = eom_address_lookup($_POST['eom-address']); //check for valid address
				if(isset($results[0])){ //take first result
       				update_post_meta( $post_id, 'eom-address', esc_attr($results[0]['formatted_address']));
					update_post_meta( $post_id, 'eom-lat', esc_attr($results[0]['lat']));
					update_post_meta( $post_id, 'eom-lng', esc_attr($results[0]['lng']));
				}
			} catch (Exception $e) {
				return;
			} 
		}
	}	
}



/**
 * catches every event that is published and publishes the associated place
 *
 * @since 5.1
 */
add_action( 'transition_post_status', 'post_unpublished_place', 10, 3 );
function post_unpublished_place( $new_status, $old_status, $post ) {
	if($post->post_type == 'eom-event'){ //if post type is eom-event
		if ( $old_status != 'publish' && $new_status == 'publish' ) { // post is published
        	if($place_id = get_post_meta( $post->ID, 'eom-place', true )){ //get eom-place id
				$place = get_post( $place_id ); //get place
				if($place->post_status != 'publish'){ //is eom-place unpublished?
					wp_update_post(array('ID' => $place->ID, 'post_status' => 'publish')); //publish it!
				}
			}
    	}
	}
}



/**
 * changes place column headers
 *
 * @since 5.0
 */
add_filter( 'manage_eom-place_posts_columns', 'change_eom_place_columns' );
function change_eom_place_columns( $columns ) {
	$columns['eom-address'] = __( 'Address', 'eom' );
	return $columns;
}



/**
 * changes event column headers
 *
 * @since 5.0
 */
add_filter( 'manage_edit-eom-event_columns', 'change_eom_event_columns' );
function change_eom_event_columns( $columns ) {
	unset($columns['date']);
	$columns['eom-date'] = __( 'Event Date', 'eom' );
	$columns['eom-place'] = __( 'Place', 'eom' );
	return $columns;
}



/**
 * makes event columns sortable
 *
 * @since 1.0
 */
add_filter( 'manage_edit-eom-event_sortable_columns', 'eom_event_sortable_columns' );
function eom_event_sortable_columns( $columns ) {
	$columns['eom-date'] = 'eom-date';
	return $columns;
}



/**
 * builds custom column data
 *
 * @since 1.0
 */
add_action( 'manage_posts_custom_column' , 'eom_custom_columns_data', 10, 2 );
function eom_custom_columns_data( $column, $post_id ) {
	switch ( $column ) {		
	case 'eom-place':
		if($place_id = get_post_meta($post_id, 'eom-place', true)){
			$status = get_post_status($place_id);
			echo '<a href="post.php?post='.$place_id.'&action=edit">'.get_the_title($place_id).'</a>';
			if ($status != 'publish'){echo ' - '.$status;}
		}
	break;
	case 'eom-date':
		if($start = get_post_meta($post_id, 'eom-date-start', true)){
			$start = date(eom_format_date('php'), $start);
		}
		if($end = get_post_meta($post_id, 'eom-date-end', true)){
			$end = date(eom_format_date('php'), $end);
		}
		echo $start.' - '.$end;
	break;
	case 'eom-address':
		echo esc_attr(get_post_meta($post_id, 'eom-address', true));
	break;
	}
}



/**
 * prepares sortable columns instructions 
 *
 * @since 1.0
 */
add_action( 'load-edit.php', 'eom_sortable_load' );
function eom_sortable_columns( $vars ) {
	// eom-event post type
	if ( isset( $vars['post_type'] ) && 'eom-event' == $vars['post_type'] ) {
		//orderby place
		if ( isset( $vars['orderby'] ) && 'eom-date' == $vars['orderby'] ) {
			$vars = array_merge(
				$vars,
				array('meta_key' => 'eom-date-start', 'orderby' => 'meta_value_num')
			);
		}
	}
	return $vars;
}



/**
 * loads sortable columns instructions 
 *
 * @since 1.0
 */
function eom_sortable_load() { 
	add_filter( 'request', 'eom_sortable_columns' ); 
}



 
/**
 * formats event and event archive list
 *
 * @since 1.0

add_filter('the_content','eom_format_event');
function eom_format_event( $content ) { 
	global $post;
	
	return '<pre>'.$content.'</pre>';
	
	if ( get_post_type() == 'eom-event' ) { 
		
		$settings = get_option( 'eom' );
		
		
		//strip span from $content
		$content = strip_tags($content, '<p><hr><strong><b>');
		
		$date_start = date(eom_format_date('php'), get_post_meta( $post->ID, 'eom-date-start', true ));
		$the_date ='<time class="entry-date" datetime="'.$date_start.'">'.$date_start.'</time>';
		
		$place = get_post(get_post_meta($post->ID, 'eom-place', true));
		$the_place = '';
		$the_map = '';
		if($place->post_status=='publish'){
			$the_place = '<a href="'.get_permalink($place->ID).'">'.esc_html($place->post_title).'</a>';
			$address = get_post_meta($place->ID, 'eom-address', true);
			$the_map = '<small>'.esc_html($address).'</small><br /><img src ="//maps.googleapis.com/maps/api/staticmap?size=500x200&maptype=roadmap&markers=color:blue%7C'.urlencode($address).'&sensor=false" />';
		}
		$the_link = '';
		if($link = get_post_meta($post->ID, 'eom-url', true)){
			$the_link = '<a href="'.esc_url($link).'" target="_blank" >'.__('Event Website','eom').'</a>';
		}
		
		
		
		if(is_single()){ // single event page
			
			$the_image = '';
			if ( has_post_thumbnail()){ // add thumbnail to the end
				$large_image_url = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), 'large');
  				$the_image = '<a href="'.$large_image_url[0].'" title="'.the_title_attribute('echo=0').'" >'.get_the_post_thumbnail($post->ID, 'large').'</a>';
				// if(isset($settings['event_image']) && $settings['event_image']=='top'){} not using this
			}
			
			$content = '<p>'.$the_place.'</p>'.$the_date.' <small><a href="?eom_ical='.$post->ID.'">'.__('Add to calendar','eom').'</a></small><div>'.$the_image.'</div>'.$content.'<div>'.$the_map.'</div>';
			
		}else{ // event list page
		
			if(isset($settings['event_excerpt_limit']) && $settings['event_excerpt_limit']==true){
				
				$content = '<p>'.$the_place.'</p>'.$the_date.'<h1>'.wp_trim_words( $content, 55, '...' ).'</h1>';
			}
			
		}
	}
	return $content;
} 
*/


/**
 * changes out post publish time for event time in event posts
 *
 */
add_filter('the_time', 'eom_filter_time');
function eom_filter_time($d){
	if(get_post_type() == 'eom-event'){
		global $post;
		return date(eom_format_date('php'), get_post_meta( $post->ID, 'eom-date-start', true ));
	}
	return $d;
}


	 
/**
 * formats single event
 *
 * @since 1.0
 */
add_filter('the_content','eom_format_event');
function eom_format_event( $content ) { 
	
	if(is_singular('eom-event')){ // single event page
		
		global $post;
		
		$settings = get_option( 'eom' );
		
		//strip span from $content
		$content = strip_tags($content, '<p><hr><strong><b>');
		
		$date_start = date(eom_format_date('php'), get_post_meta( $post->ID, 'eom-date-start', true ));
		$the_date ='<time class="entry-date" datetime="'.$date_start.'">'.$date_start.'</time>';
		
		$place = get_post(get_post_meta($post->ID, 'eom-place', true));
		$the_place = '';
		$the_map = '';
		
		if($place->post_status=='publish'){
			$the_place = '<a href="'.get_permalink($place->ID).'">'.esc_html($place->post_title).'</a>';
			$address = get_post_meta($place->ID, 'eom-address', true);
			$the_map = '<small>'.esc_html($address).'</small><br /><img src ="//maps.googleapis.com/maps/api/staticmap?size=500x200&maptype=roadmap&markers=color:blue%7C'.urlencode($address).'&sensor=false" />';
		}
		
		$the_link = '';
		if($link = get_post_meta($post->ID, 'eom-url', true)){
			$the_link = '<a href="'.esc_url($link).'" target="_blank" >'.__('Event Website','eom').'</a>';
		}
		
		$the_image = '';
		if( has_post_thumbnail()){ // add thumbnail to the end
			$large_image_url = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), 'large');
  			$the_image = '<a href="'.$large_image_url[0].'" title="'.the_title_attribute('echo=0').'" >'.get_the_post_thumbnail($post->ID, 'large').'</a>';
		}
			
		$content = '<p>'.$the_place.'</p>'.$the_date.' <small><a href="?eom_ical='.$post->ID.'">'.__('Add to calendar','eom').'</a></small><div>'.$the_image.'</div>'.$content.'<div>'.$the_map.'</div>';

	}
	return $content;
}

	 
	 
/**
 * formats single place
 *
 * @since 1.0
 */
add_filter('the_content','eom_format_place'); 
function eom_format_place( $content ) { 
	global $post;
	if ( get_post_type() == 'eom-place' ) { 
		$width = '500';
		$height = '200';
		if(is_single()){ // single page
			$address = get_post_meta($post->ID, 'eom-address', true);
			if($address){
				$content .= '<div><p>'.esc_html($address).'</p>
				<img src ="//maps.googleapis.com/maps/api/staticmap?size='.$width.'x'.$height.'&maptype=roadmap&markers=color:blue%7C'.urlencode($address).'&sensor=false" />
				</div>';
			}
			$args = array(
				'posts_per_page' => 10, 
				'meta_key' => 'eom-date-start',
				'orderby' => 'meta_value_num',	
				'post_type' => 'eom-event', 
				'post_status' => 'publish',
				'meta_query'=> array(
					'relation' => 'AND',
					array( 'key' => 'eom-date-start', 'value' => time(), 'compare' => '>'),	
					array( 'key' => 'eom-place', 'value' => $post->ID )	
				)
			);
			$events = get_posts( $args );
			if( $events ){
				$content .= '<h3>'.__('Upcoming Events','eom').'</h3><ul>';
				foreach($events as $event){
					$start = get_post_meta($event->ID, 'eom-date-start', true);
					$start = date(eom_format_date('php'), $start);
					$content .= '<li><a href="'.get_permalink($event->ID).'">'.esc_html( $event->post_title ).'</a> - '.$start.'</li>';
				}
				$content .= '</ul>';
			}	
		}
	}
	return $content;
}	 



/**
 * updates main event query 
 *
 * @since 1.0
 */
add_action( 'pre_get_posts', 'eom_update_query', 1 );
function eom_update_query( $query ) {
	
	if ( is_admin() || ! $query->is_main_query() ) return $query; //limit where this occurs

    if ( is_post_type_archive( 'eom-event' ) ) { //order all events by eom-date-start
		$query->set( 'meta_key', 'eom-date-start');
		$query->set( 'orderby', 'meta_value_num');
		$query->set( 'order', 'ASC' ); //upcoming events should be sorted by ASC
		
		//use a custom posts per page here. 
		$query->set('posts_per_page', get_option('eom_events_per_page', 10));
		//TODO: past events  should be sorted by DESC
		
		//add posts paged
		add_filter( 'posts_join' , 'eom_posts_join');//add join and where filters
		add_filter( 'posts_where', 'eom_posts_where' );
    }
	
	if ( is_post_type_archive( 'eom-place' ) ) { //order places by title
		$query->set( 'orderby', 'name');
		$query->set( 'order', 'ASC' );
    }
} 
	

	
/**
 * joins event meta to event post
 *
 * @since 1.0
 */
function eom_posts_join($join){
	remove_filter( 'posts_join', 'eom_posts_join' ); //self remove filter
	global $wpdb;
	$join .= " LEFT JOIN $wpdb->postmeta as meta ON $wpdb->posts.ID = meta.post_id";
 	return $join;
}


	
/**
 * appends where clause to event query
 *
 * @since 1.0
 */	
function eom_posts_where( $where = '' ) {
	remove_filter( 'posts_where', 'eom_posts_where' );
	$where .= " AND meta.meta_key='eom-date-end' AND meta.meta_value > ".time();
	return $where;
}



/**
 * joins postmeta for next / previous links for single event pages
 *
 * @since 1.0
 */
add_filter('get_previous_post_join', 'eom_post_join');
add_filter('get_next_post_join', 'eom_post_join');
function eom_post_join($join, $in_same_cat='', $excluded_categories='') {
	global $wpdb;
	$join = " INNER JOIN $wpdb->postmeta AS pm ON pm.post_id = p.ID";
	return $join;
}



/**
 * formats where clause for previous link
 *
 * @since 1.0
 */
add_filter('get_previous_post_where', 'eom_prev_post_where');
function eom_prev_post_where($w) {
	global $wpdb, $post;
	if( 'eom-event' == get_post_type() ) {
		$prd = get_post_meta($post->ID, 'eom-date-start', true);
		$w = $wpdb->prepare(" WHERE pm.meta_key = 'eom-date-start' AND pm.meta_value < '%s' AND p.post_type = 'eom-event' AND p.post_status = 'publish'", $prd);
	}
	return $w;
}



/**
 * formats where clause for next link
 *
 * @since 1.0
 */
add_filter('get_next_post_where', 'eom_next_post_where');
function eom_next_post_where($w) {
	global $wpdb, $post;
	if( 'eom-event' == get_post_type() ) {
		$prd = get_post_meta($post->ID, 'eom-date-start', true);
		$w = $wpdb->prepare(" WHERE pm.meta_key = 'eom-date-start' AND pm.meta_value > '%s' AND p.post_type = 'eom-event' AND p.post_status = 'publish'", $prd);
	}
	return $w;
}



/**
 * formats order by clause for previous link
 *
 * @since 1.0
 */
add_filter('get_previous_post_sort', 'eom_prev_post_sort');
function eom_prev_post_sort($o) {
	if( 'eom-event' == get_post_type() ) $o = " ORDER BY pm.meta_value DESC LIMIT 1";
	return $o;
}



/**
 * formats order by clause for next link
 *
 * @since 1.0
 */
add_filter('get_next_post_sort', 'eom_next_post_sort');
function eom_next_post_sort($o) {
	if( 'eom-event' == get_post_type() ) $o = " ORDER BY pm.meta_value ASC LIMIT 1";
	return $o;
}



/**
 * enqueues scripts and styles for admin and public pages
 *
 * @since 5.0
 */
add_action('admin_enqueue_scripts','eom_style_script');
add_action( 'wp_enqueue_scripts', 'eom_style_script' );
function eom_style_script(){
	wp_enqueue_script('jquery-ui-datepicker');
	wp_enqueue_style('jquery-ui-custom', plugins_url( 'css/jquery-ui-custom.css' , __FILE__ ) );  
	wp_enqueue_style('event-o-matic', plugins_url( 'css/event-o-matic.css' , __FILE__ ) );   	
}



/**
 * returns date format for selected type
 *
 * @param string 	$type selected date format to translate timestamp into: js, php, phpforjs
 * @return string 	formatted string
 *
 * @since 1.0
 */
function eom_format_date($type = 'php'){
	if($type == 'php'){ // php date format (uses wordpres option to display)
		$format = get_option('date_format').' '.get_option('time_format');
	}elseif($type == 'phpforjs'){ //php format for js field (when getting date into field for jquery to use)
		$format = 'n/j/Y'; 
	}else{ // how jquery will format a selected date from the picker
		$format = 'm/d/yy'; 
	}
	return $format;
}



/**
 * creates selection field for post type
 *
 * @param string 	$post_type 
 * @param string 	$selected
 * @return string 	field
 *
 * @since 1.0
 */
function eom_select_post_type($name, $post_type, $selected='', $status='publish'){
	$items = get_posts(array('post_type'=>$post_type, 'post_status'=>$status, 'posts_per_page'=>-1, 'orderby'=>'title'));
	$r = '<select name="'.$name.'" >';  
	$r .= '<option value="">'.__('Select...','eom').'</option>';
	foreach($items as $item){
		$r .= '<option value="'.$item->ID.'" '.selected( $selected, $item->ID, false).' >'.esc_attr($item->post_title).'</option>';
	}
	$r .= '</select>';
	wp_reset_postdata();
	wp_reset_query();
	return $r;
}



/**
 * adds settings link to the plugins page
 *
 * @since 5.4
 */
add_filter("plugin_action_links_".plugin_basename(__FILE__), 'eom_plugin_settings_link');
function eom_plugin_settings_link($links) { 
	$settings_link = '<a href="options-general.php?page=eom">Settings</a>'; 
	array_unshift($links, $settings_link); 
	return $links; 
}



/**
 * hooks settings page
 * 
 * @since 2.0
 */
add_action('admin_menu', 'eom_create_menu');
function eom_create_menu() {
	add_options_page(__('Event-O-Matic','eom'), __('Event-O-Matic','eom'),'manage_options','eom','eom_settings');
}



/**
 * creates settings wrapper
 * 
 * @since 2.0
 */
function eom_settings(){
	if (!current_user_can('manage_options')){ // authorized?
		wp_die( __('You do not have sufficient permissions to access this page.', 'eom'));
	}
	if(!isset($_GET['action'])) $_GET['action']=''; //action ?>
	<div class="wrap">
	<h2><?php _e( 'Event-O-Matic', 'eom' );?></h2>
	<div style="border:1px solid blue;background:#CDD8EA;margin:10px 0;padding:0px 8px;"><p>
	<form action="https://www.paypal.com/cgi-bin/webscr" method="post" style="width:125px;float:right;">
	<input type="hidden" name="cmd" value="_s-xclick">
	<input type="hidden" name="hosted_button_id" value="63XH9FAX72LRU">
	<input type="image" src="https://www.paypalobjects.com/WEBSCR-640-20110401-1/en_US/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
	<img alt="" border="0" src="https://www.paypalobjects.com/WEBSCR-640-20110401-1/en_US/i/scr/pixel.gif" width="1" height="1">
	</form>
		Event-O-Matic has been completely rewritten from the ground up to manage your events. Easier to use, easier to administer.<br /> 
		Do you like Event-O-Matic? <a href="http://wordpress.org/support/view/plugin-reviews/event-o-matic" target="_blank">Write an awesome review!</a> Having problems? <a href="http://wordpress.org/support/plugin/event-o-matic" target="_blank">Let me know!</a>
		</p>
	</div>
	
	<form method="post" action="">
	<?php eom_settings_general(); ?>
	</form>
</div>
<?php }



/**
 * creates settings page
 * 
 * @since 2.0
 */
function eom_settings_general(){
	if (!empty( $_POST ) && check_admin_referer('update_settings','eom')): // page submitted
		$settings = array( //build settings array
			'place_create'=> $_POST['place_create'],
			'place_unique'=> $_POST['place_unique'],
			'event_limit'=> $_POST['event_limit'],
			'event_image'=> $_POST['event_image'],
			'event_excerpt_limit'=> $_POST['event_excerpt_limit']
		);
		update_option( 'eom', $settings ); 
		
		//take submitted slug turn it into a slug
		update_option('eom_event_slug',sanitize_title( $_POST['eom_event_slug'], 'events' ));
		
		update_option('eom_events_per_page',sanitize_title( (int) $_POST['eom_events_per_page'], 10 ));
		
		//now flush the rewrite rules so slug works
		flush_rewrite_rules(); 
		?>
		<div class="updated"><p><strong><?php _e('Settings saved.', 'eom' ); ?></strong></p></div>
	<?php endif;
	$settings = get_option( 'eom' ); // Read in options from database ?>
	
	<h3><?php _e('Get Started','eom');?></h3>
	<p>List events on your site by creating a new page and adding the shortcodes below.</p>
	<ul>
	<li>Events are listed on this page: <strong>
	<?php printf('<a href="%1$s">%1$s</a>', get_post_type_archive_link( 'eom-event' )); ?></strong></li>
	<li>Places are listed on this page: <strong>
	<?php printf('<a href="%1$s">%1$s</a>', get_post_type_archive_link( 'eom-place' )); ?></strong></li>
	<ul><li>Use this shortcode to add an event submission form. Users must be permitted to register with your site before they can create an event: <strong>[eom-form]</strong></li>
	<!--<li>[eom-events] - Add this to list all upcoming events.</li>-->
	</ul>
	<?php
	echo wp_nonce_field( 'update_settings', 'eom'); ?>	
	<table class="form-table">
	<tr valign="top">
		<th scope="row"><?php _e('Allow public to create places:','eom');?></th>
		<td>
		<input type="hidden" name="place_create" />
		<input type="checkbox" name="place_create" value="1" <?php checked($settings['place_create']); ?> />
		<span class="description"><?php _e('Select this to allow event submitters the option to also create locations.','eom');?></span>
		</td>
	</tr>
	<tr valign="top">
		<th scope="row"><?php _e('Unique places:','eom');?></th>
		<td>
		<input type="hidden" name="place_unique" />
		<input type="checkbox" name="place_unique" value="1" <?php checked($settings['place_unique']); ?> />
		<span class="description"><?php _e('Restricts duplicate place creation.','eom');?></span>
		</td>
	</tr>
	<tr valign="top">
		<th scope="row"><?php _e('Limit content in event postings:','eom');?></th>
		<td>
		<input type="hidden" name="event_limit" />
		<input type="checkbox" name="event_limit" value="1" <?php checked($settings['event_limit']); ?> />
		<span class="description"><?php _e('Only text content will be allowed in event descriptions. External links will be removed.','eom');?></span>
		</td>
	</tr>
	<tr valign="top">
		<th scope="row"><?php _e('Image placement:','eom');?></th>
		<td>
		<select name="event_image">
			<option value="top" <?php selected( $settings['event_image'], 'top' ); ?> >Top</option>
			<option value="bottom" <?php selected( $settings['event_image'], 'bottom' ); ?> >Bottom</option>
		</select>
		</td>
	</tr>
	<tr valign="top">
		<th scope="row"><?php _e('Event slug:','eom');?></th>
		<td>
		<input type="input" name="eom_event_slug" value="<?php esc_attr_e(get_option('eom_event_slug','events')); ?>"  />
		<span class="description"><?php _e('Select the base url for events listings.','eom');?></span>
		</td>
	</tr>
	<tr valign="top">
		<th scope="row"><?php _e('Events per page:','eom');?></th>
		<td>
		<input type="input" size="3" name="eom_events_per_page" value="<?php esc_attr_e(get_option('eom_events_per_page','10')); ?>"  />
		</td>
	</tr>
	<tr valign="top">
		<th scope="row"><?php _e('Limit description to excerpt when viewing event list:','eom');?></th>
		<td>
		<input type="hidden" name="event_excerpt_limit" />
		<input type="checkbox" name="event_excerpt_limit" value="1" <?php checked($settings['event_excerpt_limit']); ?> />
		</td>
	</tr>
	</table>
	<p class="submit">
		<input type="submit" class="button-primary" value="<?php esc_attr_e('Save','eom') ?>" />
	</p>
<?php  }



/**
 * emails admin
 *
 * @since 5.0
 */
add_action( 'save_post', 'eom_email_admin' );
function eom_email_admin( $post_id ) {
	// If this is a revision or admin edits, don't send the email.
	if ( wp_is_post_revision( $post_id ) )
		return;
	if( is_admin() )
		return; 
	$post_title = get_the_title( $post_id );
	$post_url = get_permalink( $post_id );
	$subject =  sprintf(__('New Event - %s','eom'), get_bloginfo('name'));
	$message = __('A new event has been created : \n\n','eom');
	$message .= $post_title . ": " . $post_url;
	wp_mail( get_bloginfo('admin_email'), $subject, $message ); // Send email
}



/**
 * formats address from Google
 *
 * @param string 	$search the address to search for
 * @param bool		$sensor return sensor data from google
 * @return array 	formatted address data
 *
 * @since 1.0
 */
function eom_address_lookup($search, $sensor=false){
	$sensor='sensor=false';
	if($sensor){$sensor='sensor=true';}
	$url = sprintf('http://maps.googleapis.com/maps/api/geocode/json?address=%s&'.$sensor, urlencode($search));
	$ch = curl_init($url);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	$response = curl_exec($ch);
	curl_close($ch);
	$response = json_decode( $response );
	if(!$response){ //response failure
		throw new Exception(__('Message send failure. Bad request','eom'));
	}else{ //curl response success
		switch ($response->status) {
		case 'OK': //response is good, results found. parse results.
			foreach ($response->results as $key => $result){
				$a[$key]['formatted_address'] = $result->formatted_address; //full postal address
				$a[$key]['lat'] = $result->geometry->location->lat;
				$a[$key]['lng'] = $result->geometry->location->lng;
			}
			return $a;
		break;
		case 'ZERO_RESULTS': //response is good, no results found.
			return array();
		break;
		case 'OVER_QUERY_LIMIT': //response is good, query limit reached		
			throw new Exception(sprintf(__('Error. Over query limit (%s)', 'eom'), $response->status));
		break;
		default: //response error REQUEST_DENIED / INVALID_REQUEST
			throw new Exception('Geolocation error. ('.$response->status.' - '.$response->error_message.')');
		break;
		}
	}
}



/**
 * prints debug
 *
 * @since 1.0
 */
if(!function_exists('print_pre')){
	function print_pre($text){
		echo '<pre>';print_r($text);echo '</pre>';
	}
}



/**
 * adds pending bubble to admin menu events and places
 *
 * @since 5.0
 
add_action( 'admin_menu', 'add_pending_bubble' );
function add_pending_bubble() {
    global $menu;
	$event_count = wp_count_posts('eom-event');
	$place_count = wp_count_posts('eom-place');
	if ( $event_count->pending ) {
		foreach ( $menu as $key => $value ) {
			if ( $menu[$key][2] == 'edit.php?post_type=eom-event' ) {
				$menu[$key][0] .= ' <span class="update-plugins count-'.$event_count->pending.'"><span class="plugin-count">'.$event_count->pending.'</span></span>';
			}
		}
	}
	if ( $place_count->pending ) {
		foreach ( $menu as $key => $value ) {
			if ( $menu[$key][2] == 'edit.php?post_type=eom-place' ) {
				$menu[$key][0] .= ' <span class="update-plugins count-'.$place_count->pending.'"><span class="plugin-count">'.$place_count->pending.'</span></span>';
				return;
			}
		}
	}
	return;
}*/



/**
 * removes attachments on delete
 *
 * @since 5.0
 */
add_action('before_delete_post', 'eom_delete_associated');
function eom_delete_associated($id) {
	if ('eom-event' !== get_post_type($id)) return;
	$media = get_children(array( 'post_parent' => $id, 'post_type' => 'attachment' ));
	if (empty($media)) return;
    foreach ($media as $file) {
		wp_delete_attachment($file->ID);
	}
}


/**
 * redirects non-admins to page after login
 *
 * @since 5.5.6
 */
add_filter('login_redirect', 'eom_login_redirect', 10, 3);
function eom_login_redirect( $redirect_to, $request, $user ) {
	return $redirect_to;
}



/**
 * creates submission form. Uses shortcode
 *
 * @since 5.0
 */
function eom_form(){ 
	$settings = get_option( 'eom' ); // get plugin settings
	$allowed = array('jpg'=>'image/jpg','jpeg'=>'image/jpeg', 'gif'=>'image/gif', 'png'=>'image/png'); 
	global $current_user; //current user
	$error = array(); // error array
	
	ob_start(); 
	
	//form has been submitted
	if(isset($_POST['eom_nonce'])): 
			
		//form security
		if(!wp_verify_nonce($_POST['eom_nonce'],'create-event')){ wp_die('Action not allowed.'); }
	
		//files for media uploading
		require_once( ABSPATH . 'wp-admin/includes/image.php' );
		require_once( ABSPATH . 'wp-admin/includes/file.php' );
		require_once( ABSPATH . 'wp-admin/includes/media.php' );
	
		//check title
		$event_title = sanitize_text_field( $_POST['event_title'] );
		if(trim($event_title) == ''){
			$error['event_title'] = __('Add an event title.','eom');
		}
		//check description
		if($settings['event_limit']){
			$_POST['description'] = balanceTags(wp_kses($_POST['description'], array(
				'br'=>array(),
				'em' => array(), 
				'strong' => array()
			)));
		}
		if(trim($_POST['description']) == ''){
			$error['description'] = __('Add an event description.','eom');
		}
		//check date
		$date_start = strtotime($_POST['date_start'].' '.$_POST['time_start']);
		if(!$date_start){
			$error['date_start'] = __('Add an event start date.','eom');
		}
		//check hours end
		$hours_end = floatval($_POST['hours_end']);
		if(!$hours_end){
			$error['hours_end'] = __('Enter the event length in hours.','eom');
		}
		//check image
		if($_FILES['event_image']['error']!=4){ //means no file was uploaded 
			$file_type = wp_check_filetype(basename($_FILES['event_image']['name']));
			if(!in_array($file_type['type'], $allowed)) {
				$error['event_image'] = __('Filetype not allowed.','eom');
			}
		}
		//check place
		$place_title = sanitize_text_field( $_POST['place_title'] );
		$place_id = intval($_POST['place_id']);
		$place_address_results = array();
		if(isset($_POST['place_address']) && $_POST['place_address']!=''){
			try{
				$place_address_results = eom_address_lookup($_POST['place_address']); //locate address
			} catch (Exception $e) {
				$error['place_address'] = $e->getMessage();
			} 
		}
		//check uniqueness of place
		if(isset($settings['place_unique']) && $settings['place_unique']==1 && $place_address_results){
			//select any place with a similar address...
			$args = array('posts_per_page'=>'-1', 'post_type' => 'eom-place', 'meta_query' => array(array(
			'key' => 'eom-address', 'value' => $place_address_results[0]['formatted_address'])));
			$similar = get_posts($args);
			foreach($similar as $sim){
				if(strtolower($sim->post_title) == strtolower(wp_strip_all_tags($place_title))){
					$error['place_unique'] = __($sim->post_title.' - location already exists.','eom');	
					//in the future, maybe instead of an error just select that place...
					$place_title = false;
				}
			}
		}
		
		if(!$place_title && !$place_address_results){ // has place name and address?
			if(!$place_id){ // has place select?
				$error['place'] = __('Select a location to continue.','eom');
			}
		}
	
		if(count($error)): //error in form data ?>
			<div class="alert alert-error">
				<h4><?php _e('Event Is Incomplete','eom');?></h4>
				<?php _e('Fill in required fields to continue','eom');?>
				<ul><?php foreach ($error as $e){echo '<li>'.$e.'</li>';}?></ul>
			</div>
	
		<?php else: // complete form
		
			$date_end = ($hours_end * 3600) + $date_start;
			
			//process place, if needed
			if($place_title && $place_address_results){
				$place = array(
					'post_title' => wp_strip_all_tags($place_title),
					//'post_status' => 'pending',
					'post_status' => 'publish',
					'post_type' => 'eom-place',
					'post_author' => $current_user->ID,
				);
				$place_id = wp_insert_post( $place );
				if(!$place_id){
					wp_die('Error saving place. Please try again.');
				}
				update_post_meta( $place_id, 'eom-address', $place_address_results[0]['formatted_address']);
				update_post_meta( $place_id, 'eom-lat', $place_address_results[0]['lat']);
				update_post_meta( $place_id, 'eom-lng', $place_address_results[0]['lng']);
			}
			
			//process event
			$event = array(
				'post_title' => wp_strip_all_tags($event_title),
				'post_status' => 'pending',
				'post_type' => 'eom-event',
				'post_author' => $current_user->ID,
				'post_content'  => $_POST['description'],
			);
			$event_id = wp_insert_post( $event );
			if(!$event_id){
				wp_die('Error saving event. Please try again.');
			}
			//add post meta
			add_post_meta($event_id, 'eom-place', $place_id);
			add_post_meta($event_id, 'eom-date-start', $date_start);
			add_post_meta($event_id, 'eom-date-end', $date_end);
			add_post_meta($event_id, 'eom-url', esc_url_raw($_POST['website'],array('http','https')));
			//add custom tax
			if(isset($_POST['event_cat'])){
				wp_set_object_terms( $event_id, (int) $_POST['event_cat'], 'eom-event-cats');
			}
			//add image if set
			if(isset($_FILES['event_image']) && $_FILES['event_image']['error']!=4){
				$attachment_id = media_handle_upload( 'event_image', $event_id );
				if(is_wp_error( $attachment_id )){
					//error uploading
					echo $attachment_id->get_error_message();
					exit();
				}else{
					set_post_thumbnail($event_id, $attachment_id);
				}
			}
		
			$address = get_post_meta($place_id, 'eom-address', true); ?>
				
			<div class="alert alert-success">
				<h3><?php _e('Event Saved','eom');?></h3>
				<p><a href="<?php echo home_url(); ?>">
					<?php printf(__('Return to %s', 'eom'), get_bloginfo('name'));?>
				</a></p>
			</div>
				
			<div class="eom-preview">
				<?php if (has_post_thumbnail($event_id)){
					echo get_the_post_thumbnail($event_id, 'thumbnail'); 
				}?>
				<h2><?php esc_html_e( $event['post_title'] ); ?></h2>
				<time class="entry-date"><?php date(eom_format_date('php'), $date_start); ?></time>
				<?php //echo date(eom_format_date('php'), $eom_date_end);?>
				<p><?php echo $event['post_content']; ?></p>
				<p><strong><?php esc_html_e(get_the_title($place_id));?></strong><br />
				<small><?php esc_html_e($address); ?></small></p>
				<img src ="//maps.googleapis.com/maps/api/staticmap?size=500x200&markers=color:blue%7C<?php echo urlencode($address);?>&sensor=false" />
			</div>
			<?php return ?>	
		<?php endif; //error check ?>	
	<?php endif; //form submitted ?>

<?php if(is_user_logged_in()): ?>

<form method="post" class="event-form" enctype="multipart/form-data" >
<p><?php _e('Required fields are marked','eom');?> <span class="required">*</span></p>
<p class="logged-in-as" >
	<?php echo get_avatar( $current_user->user_email, 25, '', $current_user->ID); ?>
	<?php printf(__(' Logged in as %s. <a href="%s">Log out?</a>'),
		$current_user->display_name,
		wp_logout_url(get_permalink())); 
	?>
</p>
<p>
	<label for="event_title"><?php _e('Title','eom')?> <span class="required">*</span></label>
	<input type="text" name="event_title" class="title" value="<?php (isset($_POST['event_title']) ? esc_attr_e($_POST['event_title']):''); ?>" />
</p>
<p>
	<label><?php _e('Description','eom')?> <span class="required">*</span></label>
	<?php if($settings['event_limit']): // simple editor ?>
		<textarea name="description" rows="8"><?php if(isset($_POST['description'])){ echo esc_textarea(stripslashes($_POST['description']));} ?></textarea>
		<span class="description"><?php _e('Text only. Links will be removed from event posting','eom');?></span>
	<?php else:
	 wp_editor( (isset($_POST['description']) ? esc_textarea($_POST['description']):''), 'e', array('media_buttons'=>false,'teeny'=>true,'textarea_name'=>'description'));
	 endif;
	?>
</p>
<p>
<?php $event_cat_form = wp_dropdown_categories(array(
	'option_none_value'  => '-1',
	'echo' => false,
	'orderby'            => 'NAME', 
	'hide_empty'         => 0, 
	'name'               => 'event_cat',
	'taxonomy'           => 'eom-event-cats',
	'hide_if_empty'      => true,
	'value_field'	     => 'event_cat_id',	
));
if($event_cat_form){?>
	<label><?php _e('Event Category','eom');?></label>
	<?php echo $event_cat_form;
}?>
</p>
<p>
	<label><?php _e('Event Date', 'eom'); ?> <span class="required">*</span></label>
	<?php 
	$start = (isset($_POST['date_start']) ? $_POST['date_start']: '' );
	eom_date_field('date_start' , $start);
	eom_time_select('time_start');
	 _e(' and ends ','eom')?>
	<input type="text" name="hours_end" size="2" value="<?php echo (isset($_POST['hours_end']) ? esc_attr($_POST['hours_end']) : '' ); ?>" />
	<?php _e(' hours later.','eom')?>
</p>
<p>
	<label><?php _e('Location','eom'); ?> <span class="required">*</span></label>
	<?php if($settings['place_create']):?> 
		<span class="description"><?php _e('Select or enter in a new location name and address.','eom'); ?></span>
	<?php endif; ?>
	<table><tr>
		<td><?php echo eom_select_post_type('place_id', 'eom-place', (isset($_POST['place_id']) ? $_POST['place_id']:'')); ?></td>
		<td>
			<?php if($settings['place_create']):?>
				<p>
				<label for="place_title"><?php _e('Name','eom')?></label>
				<input type="text" name="place_title" value="<?php echo (isset($_POST['place_title']) ? $_POST['place_title']:'');?>" />
				</p>
				<p>
				<label for="place_address"><?php _e('Address','eom')?></label>
				<input type="text" name="place_address" value="<?php echo (isset($_POST['place_address']) ? $_POST['place_address']:'');?>" />
				</p>
			<?php endif; ?>
		</td>
	</tr></table>
</p>
<p>
	<label for="website"><?php _e('Website Link','eom')?></label>
	<input type="text" name="website" class="title" value="<?php (isset($_POST['website']) ? esc_attr_e($_POST['website']):''); ?>" />
</p>
<p>
<label><?php _e('Image','eom')?></label>
	<input type="file" name="event_image" multiple="false" />
	<span class="description"><?php _e('Image files only.','eom'); ?></span>
</p>
<?php wp_nonce_field( 'create-event', 'eom_nonce' ); //build nonce ?>
<p><input type="submit" value="<?php _e('Submit Event','eom');?>"></p>
</form>
<?php else: //not logged in 
	printf(__('<p><a href="%s">Login</a> to create a new event.</p>','eom'), wp_login_url( get_permalink()) );
	wp_register( 'New User? ', ' an account to get started.'); 
endif; ?>

	<?php $output = ob_get_contents(); // Output the content
	ob_end_clean();
	if (is_page()){ return $output; }
}
add_shortcode('eom-form', 'eom_form');



/**
 * formats datepicker
 *
 * @since 5.0
 */
function eom_date_field($name, $value=''){
	if(!$value){ $value = time(); }else{$value = strtotime($value);}?>
	<script type="text/javascript" charset="utf-8">
	jQuery(document).ready(function($){
		$( "#<?php echo $name?>" ).datepicker({
      		dateFormat: "<?php echo eom_format_date('js');?>"
    	});
  	});
  	</script> 
	<input type="text" id="<?php echo $name;?>" name="<?php echo $name; ?>" size="8" value="<?php echo date(eom_format_date('phpforjs'), $value);?>" />
	<?php 
}



/**
 * creates time selection field
 *
 * @param string 	$name name of field
 * @param int 		$val selected value of date as unix timestamp
 * @return string 	time field
 */
function eom_time_select($name, $val=false){
	$form = '<select name="'.$name.'" >';
	for ($i = 0; $i < 24; $i++){
		$osel='';
		$hsel='';
		if($val){
			$time = date('G:i', $val);
			if(($i.':00')==$time){$osel='selected="selected"';}
			if(($i.':30')==$time){$hsel='selected="selected"';}
		}
		$j=$i;
		if($i==0){$j=12;$ap='am';}
		if($i>12){$j=$j-12;$ap='pm';}
		if($i==12){$ap='pm';}
		$form.='<option value="'.$i.':00" '.$osel.'>'.$j.':00 '.$ap.' </option>';
		$form.='<option value="'.$i.':30" '.$hsel.'>'.$j.':30 '.$ap.' </option>';
	}
	$form.='</select>';
	echo $form;
}



/**
 * adds EOM meta box into nav menu admin  
 *
 */
add_action( 'admin_head-nav-menus.php', 'eom_menu_meta_box' );
	function eom_menu_meta_box() {
    	add_meta_box( 'add-cpt', __('Event-O-Matic', 'default'), 'eom_meta_box', 'nav-menus', 'side');
}



/**
 * adds EOM meta box into nav menu admin  
 *
 */
function eom_meta_box() { ?>
	<div id="posttype-wl-login" class="posttypediv">
		<div id="tabs-panel-wishlist-login" class="tabs-panel tabs-panel-active">
			<ul id ="wishlist-login-checklist" class="categorychecklist form-no-clear">
				<li>
					<label class="menu-item-title">
					<input type="checkbox" class="menu-item-checkbox" name="menu-item[-1][menu-item-object-id]" value="-1"><?php _e('Upcoming Events','eom');?>
					</label>
					<input type="hidden" class="menu-item-type" name="menu-item[-1][menu-item-type]" value="custom">
				<input type="hidden" class="menu-item-title" name="menu-item[-1][menu-item-title]" value="<?php _e('Events', 'eom');?>">
					<input type="hidden" class="menu-item-url" name="menu-item[-1][menu-item-url]" value="<?php echo get_post_type_archive_link( 'eom-event' ); ?>">
				</li>
			</ul>
		</div>
		<p class="button-controls">
			<span class="add-to-menu">
				<input type="submit" class="button-secondary submit-add-to-menu right" value="<?php _e('Add to Menu','eom');?>" name="add-post-type-menu-item" id="submit-posttype-wl-login">
				<span class="spinner"></span>
			</span>
		</p>
	</div>
<?php }





/**
 * invokes webcal file format
 *
 */
add_action('init', 'eom_ical');
function eom_ical($wpvarstoreset){
	if(isset($_GET['eom_ical']) ){

		$name = preg_replace('/([\\,;])/','\\\\$1',get_bloginfo_rss('name'));
		$filename = preg_replace('/[^0-9a-zA-Z]/','',$name).'.ics'; 
		header("Content-Type: text/calendar; charset=" . get_option('blog_charset'));
		header("Content-Disposition: inline; filename=$filename");
		header('Expires: Wed, 11 Jan 1984 05:00:00 GMT');
		header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
		header('Cache-Control: no-cache, must-revalidate, max-age=0');
		header('Pragma: no-cache');

		echo "BEGIN:VCALENDAR\r\n";
		echo "VERSION:2.0\r\n";
  		echo "X-WR-CALNAME:$name\r\n";

		if(is_numeric($_GET['eom_ical'])){ // one event id
			
			$event = get_post($_GET['eom_ical']);
			$place = get_post(get_post_meta($event->ID, 'eom-place', true));
			$start = get_post_meta( $event->ID, 'eom-date-start', true );
			$end = get_post_meta( $event->ID, 'eom-date-end', true );
			$address = get_post_meta($place->ID, 'eom-address', true);
	
			
			if($event->post_status=='publish'){ // published only
				$summary = preg_replace('/([\\,;])/','\\\\$1', apply_filters( 'the_title', $event->post_title ));
				$permalink = get_permalink( $event->ID );
				
				echo "BEGIN:VEVENT\r\n";
				echo "SUMMARY:$summary\r\n";
				echo "URL;VALUE=URI:$permalink\r\n";
				echo "UID:$permalink\r\n";
				
				// Strip out newlines here:
				$description=preg_replace('/[ \r\n]+/',' ',$place->post_title.' - '.$address.' - '.strip_tags(
				apply_filters( 'the_content', $event->post_content )).' ');
				$description=preg_replace('/([\\,;])/','\\\\$1',$description);
				$description.='['.sprintf(__('by: %s'),$name).']';
				
				echo "DESCRIPTION:$description\r\n";
				echo "TRANSP:TRANSPARENT\r\n"; // for availability.
				echo sprintf("DTSTART;VALUE=DATE-TIME:%s\r\n",date('Ymd\THis\Z',$start));
        		echo sprintf("DTEND;VALUE=DATE-TIME:%s\r\n",date('Ymd\THis\Z',$end));
				echo "END:VEVENT\r\n";
			}
		}
		/*if($_GET['eom_ical']=='upcoming'){ //all upcoming events
			$events=$event->getAll(array('status'=>$event->statusCode['approved'],'when'=>'upcoming','order'=>'dateStart','orderDirection'=>'DESC'));
			foreach($events as $event){
				$summary = preg_replace('/([\\,;])/','\\\\$1',$event['name']);
     			$permalink = get_option('eom_events_url').'?id='.$event['id'];	 
				echo "BEGIN:VEVENT\r\n";
      			echo "SUMMARY:$summary\r\n";
      			echo "URL;VALUE=URI:$permalink\r\n";
      			echo "UID:$permalink\r\n";
      			// So just strip out newlines here:
				$description=preg_replace('/[ \r\n]+/',' ',$event['venueName'].' - '.strip_tags($event['description']).' ');
        		$description=preg_replace('/([\\,;])/','\\\\$1',$description);
    			$description.='['.sprintf(__('by: %s'),$name).']';
      			echo "DESCRIPTION:$description\r\n";
      			echo "TRANSP:TRANSPARENT\r\n"; // for availability.

				echo sprintf("DTSTART;VALUE=DATE-TIME:%s\r\n",gmdate('Ymd\THis\Z',strtotime($event['dateStart'])));
        		echo sprintf("DTEND;VALUE=DATE-TIME:%s\r\n",gmdate('Ymd\THis\Z',strtotime($event['dateEnd'])));
				echo "END:VEVENT\r\n";

			}
		} */
		echo "END:VCALENDAR\r\n";
  		exit(0);
	}
	return $wpvarstoreset;
}



/**
 * includes widget 
 *
 * @since 5.0
 */
include('widget.php');